# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_fields.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15sessions_fields.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\"S\n\x0fSessionRawField\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sessions.SessionRawEnumField\"S\n\x0fTaskOptionField\x12@\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sessions.TaskOptionEnumField\"\'\n\x16TaskOptionGenericField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\x8a\x02\n\x0cSessionField\x12J\n\x11session_raw_field\x18\x01 \x01(\x0b\x32-.armonik.api.grpc.v1.sessions.SessionRawFieldH\x00\x12J\n\x11task_option_field\x18\x02 \x01(\x0b\x32-.armonik.api.grpc.v1.sessions.TaskOptionFieldH\x00\x12Y\n\x19task_option_generic_field\x18\x03 \x01(\x0b\x32\x34.armonik.api.grpc.v1.sessions.TaskOptionGenericFieldH\x00\x42\x07\n\x05\x66ield*\xca\x02\n\x13SessionRawEnumField\x12&\n\"SESSION_RAW_ENUM_FIELD_UNSPECIFIED\x10\x00\x12%\n!SESSION_RAW_ENUM_FIELD_SESSION_ID\x10\x01\x12!\n\x1dSESSION_RAW_ENUM_FIELD_STATUS\x10\x02\x12(\n$SESSION_RAW_ENUM_FIELD_PARTITION_IDS\x10\x03\x12\"\n\x1eSESSION_RAW_ENUM_FIELD_OPTIONS\x10\x04\x12%\n!SESSION_RAW_ENUM_FIELD_CREATED_AT\x10\x05\x12\'\n#SESSION_RAW_ENUM_FIELD_CANCELLED_AT\x10\x06\x12#\n\x1fSESSION_RAW_ENUM_FIELD_DURATION\x10\x07*\xc3\x03\n\x13TaskOptionEnumField\x12&\n\"TASK_OPTION_ENUM_FIELD_UNSPECIFIED\x10\x00\x12\'\n#TASK_OPTION_ENUM_FIELD_MAX_DURATION\x10\x01\x12&\n\"TASK_OPTION_ENUM_FIELD_MAX_RETRIES\x10\x02\x12#\n\x1fTASK_OPTION_ENUM_FIELD_PRIORITY\x10\x03\x12\'\n#TASK_OPTION_ENUM_FIELD_PARTITION_ID\x10\x04\x12+\n\'TASK_OPTION_ENUM_FIELD_APPLICATION_NAME\x10\x05\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_VERSION\x10\x06\x12\x30\n,TASK_OPTION_ENUM_FIELD_APPLICATION_NAMESPACE\x10\x07\x12.\n*TASK_OPTION_ENUM_FIELD_APPLICATION_SERVICE\x10\x08\x12&\n\"TASK_OPTION_ENUM_FIELD_ENGINE_TYPE\x10\tB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_fields_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _globals['_SESSIONRAWENUMFIELD']._serialized_start=536
  _globals['_SESSIONRAWENUMFIELD']._serialized_end=866
  _globals['_TASKOPTIONENUMFIELD']._serialized_start=869
  _globals['_TASKOPTIONENUMFIELD']._serialized_end=1320
  _globals['_SESSIONRAWFIELD']._serialized_start=55
  _globals['_SESSIONRAWFIELD']._serialized_end=138
  _globals['_TASKOPTIONFIELD']._serialized_start=140
  _globals['_TASKOPTIONFIELD']._serialized_end=223
  _globals['_TASKOPTIONGENERICFIELD']._serialized_start=225
  _globals['_TASKOPTIONGENERICFIELD']._serialized_end=264
  _globals['_SESSIONFIELD']._serialized_start=267
  _globals['_SESSIONFIELD']._serialized_end=533
# @@protoc_insertion_point(module_scope)
