# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import sessions_common_pb2 as sessions__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16sessions_service.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\x1a\x15sessions_common.proto2\xf0\x02\n\x08Sessions\x12u\n\x0cListSessions\x12\x31.armonik.api.grpc.v1.sessions.ListSessionsRequest\x1a\x32.armonik.api.grpc.v1.sessions.ListSessionsResponse\x12q\n\nGetSession\x12/.armonik.api.grpc.v1.sessions.GetSessionRequest\x1a\x30.armonik.api.grpc.v1.sessions.GetSessionResponse\"\x00\x12z\n\rCancelSession\x12\x32.armonik.api.grpc.v1.sessions.CancelSessionRequest\x1a\x33.armonik.api.grpc.v1.sessions.CancelSessionResponse\"\x00\x42\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _globals['_SESSIONS']._serialized_start=80
  _globals['_SESSIONS']._serialized_end=448
# @@protoc_insertion_point(module_scope)
