# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import result_status_pb2 as result__status__pb2
from . import results_fields_pb2 as results__fields__pb2
from . import results_filters_pb2 as results__filters__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14results_common.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13result_status.proto\x1a\x14results_fields.proto\x1a\x15results_filters.proto\x1a\x14sort_direction.proto\"\xfa\x01\n\tResultRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tresult_id\x18\x08 \x01(\t\"\xb8\x02\n\x12ListResultsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x35\n\x07\x66ilters\x18\x03 \x01(\x0b\x32$.armonik.api.grpc.v1.results.Filters\x12\x42\n\x04sort\x18\x04 \x01(\x0b\x32\x34.armonik.api.grpc.v1.results.ListResultsRequest.Sort\x1a\x85\x01\n\x04Sort\x12\x37\n\x05\x66ield\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.results.ResultField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"~\n\x13ListResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"%\n\x10GetResultRequest\x12\x11\n\tresult_id\x18\x01 \x01(\t\"K\n\x11GetResultResponse\x12\x36\n\x06result\x18\x01 \x01(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\">\n\x15GetOwnerTaskIdRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"\xb9\x01\n\x16GetOwnerTaskIdResponse\x12V\n\x0bresult_task\x18\x01 \x03(\x0b\x32\x41.armonik.api.grpc.v1.results.GetOwnerTaskIdResponse.MapResultTask\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x33\n\rMapResultTask\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\"\xa9\x01\n\x1c\x43reateResultsMetaDataRequest\x12W\n\x07results\x18\x01 \x03(\x0b\x32\x46.armonik.api.grpc.v1.results.CreateResultsMetaDataRequest.ResultCreate\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x1c\n\x0cResultCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\"X\n\x1d\x43reateResultsMetaDataResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\"\xa7\x01\n\x14\x43reateResultsRequest\x12O\n\x07results\x18\x01 \x03(\x0b\x32>.armonik.api.grpc.v1.results.CreateResultsRequest.ResultCreate\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a*\n\x0cResultCreate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"P\n\x15\x43reateResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\"\xc7\x01\n\x17UploadResultDataRequest\x12S\n\x02id\x18\x01 \x01(\x0b\x32\x45.armonik.api.grpc.v1.results.UploadResultDataRequest.ResultIdentifierH\x00\x12\x14\n\ndata_chunk\x18\x02 \x01(\x0cH\x00\x1a\x39\n\x10ResultIdentifier\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\tB\x06\n\x04type\"R\n\x18UploadResultDataResponse\x12\x36\n\x06result\x18\x01 \x01(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\"B\n#ResultsServiceConfigurationResponse\x12\x1b\n\x13\x64\x61ta_chunk_max_size\x18\x01 \x01(\x05\"B\n\x19\x44ownloadResultDataRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\t\"0\n\x1a\x44ownloadResultDataResponse\x12\x12\n\ndata_chunk\x18\x01 \x01(\x0c\"A\n\x18\x44\x65leteResultsDataRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"B\n\x19\x44\x65leteResultsDataResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\tB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _globals['_RESULTRAW']._serialized_start=175
  _globals['_RESULTRAW']._serialized_end=425
  _globals['_LISTRESULTSREQUEST']._serialized_start=428
  _globals['_LISTRESULTSREQUEST']._serialized_end=740
  _globals['_LISTRESULTSREQUEST_SORT']._serialized_start=607
  _globals['_LISTRESULTSREQUEST_SORT']._serialized_end=740
  _globals['_LISTRESULTSRESPONSE']._serialized_start=742
  _globals['_LISTRESULTSRESPONSE']._serialized_end=868
  _globals['_GETRESULTREQUEST']._serialized_start=870
  _globals['_GETRESULTREQUEST']._serialized_end=907
  _globals['_GETRESULTRESPONSE']._serialized_start=909
  _globals['_GETRESULTRESPONSE']._serialized_end=984
  _globals['_GETOWNERTASKIDREQUEST']._serialized_start=986
  _globals['_GETOWNERTASKIDREQUEST']._serialized_end=1048
  _globals['_GETOWNERTASKIDRESPONSE']._serialized_start=1051
  _globals['_GETOWNERTASKIDRESPONSE']._serialized_end=1236
  _globals['_GETOWNERTASKIDRESPONSE_MAPRESULTTASK']._serialized_start=1185
  _globals['_GETOWNERTASKIDRESPONSE_MAPRESULTTASK']._serialized_end=1236
  _globals['_CREATERESULTSMETADATAREQUEST']._serialized_start=1239
  _globals['_CREATERESULTSMETADATAREQUEST']._serialized_end=1408
  _globals['_CREATERESULTSMETADATAREQUEST_RESULTCREATE']._serialized_start=1380
  _globals['_CREATERESULTSMETADATAREQUEST_RESULTCREATE']._serialized_end=1408
  _globals['_CREATERESULTSMETADATARESPONSE']._serialized_start=1410
  _globals['_CREATERESULTSMETADATARESPONSE']._serialized_end=1498
  _globals['_CREATERESULTSREQUEST']._serialized_start=1501
  _globals['_CREATERESULTSREQUEST']._serialized_end=1668
  _globals['_CREATERESULTSREQUEST_RESULTCREATE']._serialized_start=1626
  _globals['_CREATERESULTSREQUEST_RESULTCREATE']._serialized_end=1668
  _globals['_CREATERESULTSRESPONSE']._serialized_start=1670
  _globals['_CREATERESULTSRESPONSE']._serialized_end=1750
  _globals['_UPLOADRESULTDATAREQUEST']._serialized_start=1753
  _globals['_UPLOADRESULTDATAREQUEST']._serialized_end=1952
  _globals['_UPLOADRESULTDATAREQUEST_RESULTIDENTIFIER']._serialized_start=1887
  _globals['_UPLOADRESULTDATAREQUEST_RESULTIDENTIFIER']._serialized_end=1944
  _globals['_UPLOADRESULTDATARESPONSE']._serialized_start=1954
  _globals['_UPLOADRESULTDATARESPONSE']._serialized_end=2036
  _globals['_RESULTSSERVICECONFIGURATIONRESPONSE']._serialized_start=2038
  _globals['_RESULTSSERVICECONFIGURATIONRESPONSE']._serialized_end=2104
  _globals['_DOWNLOADRESULTDATAREQUEST']._serialized_start=2106
  _globals['_DOWNLOADRESULTDATAREQUEST']._serialized_end=2172
  _globals['_DOWNLOADRESULTDATARESPONSE']._serialized_start=2174
  _globals['_DOWNLOADRESULTDATARESPONSE']._serialized_end=2222
  _globals['_DELETERESULTSDATAREQUEST']._serialized_start=2224
  _globals['_DELETERESULTSDATAREQUEST']._serialized_end=2289
  _globals['_DELETERESULTSDATARESPONSE']._serialized_start=2291
  _globals['_DELETERESULTSDATARESPONSE']._serialized_end=2357
# @@protoc_insertion_point(module_scope)
