# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: result_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13result_status.proto\x12!armonik.api.grpc.v1.result_status*\x9c\x01\n\x0cResultStatus\x12\x1d\n\x19RESULT_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15RESULT_STATUS_CREATED\x10\x01\x12\x1b\n\x17RESULT_STATUS_COMPLETED\x10\x02\x12\x19\n\x15RESULT_STATUS_ABORTED\x10\x03\x12\x1a\n\x16RESULT_STATUS_NOTFOUND\x10\x7f\x42\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'result_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _globals['_RESULTSTATUS']._serialized_start=59
  _globals['_RESULTSTATUS']._serialized_end=215
# @@protoc_insertion_point(module_scope)
