# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: filters_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x66ilters_common.proto\x12\x13\x61rmonik.api.grpc.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\x0c\x46ilterString\x12\r\n\x05value\x18\x01 \x01(\t\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterStringOperator\"Z\n\x0c\x46ilterNumber\x12\r\n\x05value\x18\x01 \x01(\x03\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterNumberOperator\"r\n\nFilterDate\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x08operator\x18\x02 \x01(\x0e\x32\'.armonik.api.grpc.v1.FilterDateOperator\"X\n\x0b\x46ilterArray\x12\r\n\x05value\x18\x01 \x01(\t\x12:\n\x08operator\x18\x02 \x01(\x0e\x32(.armonik.api.grpc.v1.FilterArrayOperator\"\\\n\rFilterBoolean\x12\r\n\x05value\x18\x01 \x01(\x08\x12<\n\x08operator\x18\x02 \x01(\x0e\x32*.armonik.api.grpc.v1.FilterBooleanOperator*\xfa\x01\n\x14\x46ilterStringOperator\x12 \n\x1c\x46ILTER_STRING_OPERATOR_EQUAL\x10\x00\x12$\n FILTER_STRING_OPERATOR_NOT_EQUAL\x10\x01\x12#\n\x1f\x46ILTER_STRING_OPERATOR_CONTAINS\x10\x02\x12\'\n#FILTER_STRING_OPERATOR_NOT_CONTAINS\x10\x03\x12&\n\"FILTER_STRING_OPERATOR_STARTS_WITH\x10\x04\x12$\n FILTER_STRING_OPERATOR_ENDS_WITH\x10\x05*\x8e\x02\n\x14\x46ilterNumberOperator\x12 \n\x1c\x46ILTER_NUMBER_OPERATOR_EQUAL\x10\x00\x12$\n FILTER_NUMBER_OPERATOR_NOT_EQUAL\x10\x01\x12$\n FILTER_NUMBER_OPERATOR_LESS_THAN\x10\x02\x12-\n)FILTER_NUMBER_OPERATOR_LESS_THAN_OR_EQUAL\x10\x03\x12\x30\n,FILTER_NUMBER_OPERATOR_GREATER_THAN_OR_EQUAL\x10\x04\x12\'\n#FILTER_NUMBER_OPERATOR_GREATER_THAN\x10\x05*\xec\x01\n\x12\x46ilterDateOperator\x12\x1e\n\x1a\x46ILTER_DATE_OPERATOR_EQUAL\x10\x00\x12\"\n\x1e\x46ILTER_DATE_OPERATOR_NOT_EQUAL\x10\x01\x12\x1f\n\x1b\x46ILTER_DATE_OPERATOR_BEFORE\x10\x02\x12(\n$FILTER_DATE_OPERATOR_BEFORE_OR_EQUAL\x10\x03\x12\'\n#FILTER_DATE_OPERATOR_AFTER_OR_EQUAL\x10\x04\x12\x1e\n\x1a\x46ILTER_DATE_OPERATOR_AFTER\x10\x05*a\n\x13\x46ilterArrayOperator\x12\"\n\x1e\x46ILTER_ARRAY_OPERATOR_CONTAINS\x10\x00\x12&\n\"FILTER_ARRAY_OPERATOR_NOT_CONTAINS\x10\x01*^\n\x14\x46ilterStatusOperator\x12 \n\x1c\x46ILTER_STATUS_OPERATOR_EQUAL\x10\x00\x12$\n FILTER_STATUS_OPERATOR_NOT_EQUAL\x10\x01*7\n\x15\x46ilterBooleanOperator\x12\x1e\n\x1a\x46ILTER_BOOLEAN_OPERATOR_IS\x10\x00\x42\x16\xaa\x02\x13\x41rmonik.Api.gRPC.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'filters_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023Armonik.Api.gRPC.V1'
  _globals['_FILTERSTRINGOPERATOR']._serialized_start=563
  _globals['_FILTERSTRINGOPERATOR']._serialized_end=813
  _globals['_FILTERNUMBEROPERATOR']._serialized_start=816
  _globals['_FILTERNUMBEROPERATOR']._serialized_end=1086
  _globals['_FILTERDATEOPERATOR']._serialized_start=1089
  _globals['_FILTERDATEOPERATOR']._serialized_end=1325
  _globals['_FILTERARRAYOPERATOR']._serialized_start=1327
  _globals['_FILTERARRAYOPERATOR']._serialized_end=1424
  _globals['_FILTERSTATUSOPERATOR']._serialized_start=1426
  _globals['_FILTERSTATUSOPERATOR']._serialized_end=1520
  _globals['_FILTERBOOLEANOPERATOR']._serialized_start=1522
  _globals['_FILTERBOOLEANOPERATOR']._serialized_end=1577
  _globals['_FILTERSTRING']._serialized_start=78
  _globals['_FILTERSTRING']._serialized_end=168
  _globals['_FILTERNUMBER']._serialized_start=170
  _globals['_FILTERNUMBER']._serialized_end=260
  _globals['_FILTERDATE']._serialized_start=262
  _globals['_FILTERDATE']._serialized_end=376
  _globals['_FILTERARRAY']._serialized_start=378
  _globals['_FILTERARRAY']._serialized_end=466
  _globals['_FILTERBOOLEAN']._serialized_start=468
  _globals['_FILTERBOOLEAN']._serialized_end=560
# @@protoc_insertion_point(module_scope)
