# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_filters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import filters_common_pb2 as filters__common__pb2
from . import task_status_pb2 as task__status__pb2
from . import tasks_fields_pb2 as tasks__fields__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13tasks_filters.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x14\x66ilters_common.proto\x1a\x11task_status.proto\x1a\x12tasks_fields.proto\"\x87\x01\n\x0c\x46ilterStatus\x12:\n\x05value\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12;\n\x08operator\x18\x02 \x01(\x0e\x32).armonik.api.grpc.v1.FilterStatusOperator\"\xbf\x03\n\x0b\x46ilterField\x12\x33\n\x05\x66ield\x18\x01 \x01(\x0b\x32$.armonik.api.grpc.v1.tasks.TaskField\x12:\n\rfilter_string\x18\x02 \x01(\x0b\x32!.armonik.api.grpc.v1.FilterStringH\x00\x12:\n\rfilter_number\x18\x03 \x01(\x0b\x32!.armonik.api.grpc.v1.FilterNumberH\x00\x12<\n\x0e\x66ilter_boolean\x18\x04 \x01(\x0b\x32\".armonik.api.grpc.v1.FilterBooleanH\x00\x12@\n\rfilter_status\x18\x05 \x01(\x0b\x32\'.armonik.api.grpc.v1.tasks.FilterStatusH\x00\x12\x36\n\x0b\x66ilter_date\x18\x06 \x01(\x0b\x32\x1f.armonik.api.grpc.v1.FilterDateH\x00\x12\x38\n\x0c\x66ilter_array\x18\x07 \x01(\x0b\x32 .armonik.api.grpc.v1.FilterArrayH\x00\x42\x11\n\x0fvalue_condition\"A\n\nFiltersAnd\x12\x33\n\x03\x61nd\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.FilterField\"<\n\x07\x46ilters\x12\x31\n\x02or\x18\x01 \x03(\x0b\x32%.armonik.api.grpc.v1.tasks.FiltersAndB\x1c\xaa\x02\x19\x41rmonik.Api.gRPC.V1.Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_filters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031Armonik.Api.gRPC.V1.Tasks'
  _globals['_FILTERSTATUS']._serialized_start=112
  _globals['_FILTERSTATUS']._serialized_end=247
  _globals['_FILTERFIELD']._serialized_start=250
  _globals['_FILTERFIELD']._serialized_end=697
  _globals['_FILTERSAND']._serialized_start=699
  _globals['_FILTERSAND']._serialized_end=764
  _globals['_FILTERS']._serialized_start=766
  _globals['_FILTERS']._serialized_end=826
# @@protoc_insertion_point(module_scope)
